@@ -102,7 +102,7 @@ pub(super) fn execute(repo: OpenRepository, opts: Opts, ignore_snaps: Vec<Id>) -
     };
 
     // list existing pack files
-    let p = progress_spinner("geting packs from repository...");
+    let p = progress_spinner("getting packs from repository...");
     let existing_packs: HashMap<_, _> = be.list_with_size(FileType::Pack)?.into_iter().collect();
     p.finish();
 
@@ -799,7 +799,7 @@ impl Pruner {
         // total_size_of_all_blobs + total_size_of_pack_headers + #packs * pack_overhead
         // This is hard/impossible to compute because:
         // - the size of blobs can change during repacking if compression is changed
-        // - the size of pack headers depends on wheter blobs are compressed or not
+        // - the size of pack headers depends on whether blobs are compressed or not
         // - we don't know the number of packs generated by repacking
         // So, we simply use the current size of the blobs and an estimation of the pack
         // header size.
