@@ -21,6 +21,7 @@ use serde_with::{serde_as, DisplayFromStr};
 
 use super::Id;
 use crate::backend::{DecryptReadBackend, FileType, RepoFile};
+use crate::repository::parse_command;
 
 #[serde_as]
 #[derive(Clone, Default, Parser, Deserialize, Merge)]
@@ -360,7 +361,7 @@ impl SnapshotFile {
             && (filter.filter_label.is_empty() || filter.filter_label.contains(&self.label))
     }
 
-    /// Add tag lists to snapshot. return wheter snapshot was changed
+    /// Add tag lists to snapshot. return whether snapshot was changed
     pub fn add_tags(&mut self, tag_lists: Vec<StringList>) -> bool {
         let old_tags = self.tags.clone();
         self.tags.add_all(tag_lists);
@@ -369,7 +370,7 @@ impl SnapshotFile {
         old_tags != self.tags
     }
 
-    /// Set tag lists to snapshot. return wheter snapshot was changed
+    /// Set tag lists to snapshot. return whether snapshot was changed
     pub fn set_tags(&mut self, tag_lists: Vec<StringList>) -> bool {
         let old_tags = std::mem::take(&mut self.tags);
         self.tags.add_all(tag_lists);
@@ -378,7 +379,7 @@ impl SnapshotFile {
         old_tags != self.tags
     }
 
-    /// Remove tag lists from snapshot. return wheter snapshot was changed
+    /// Remove tag lists from snapshot. return whether snapshot was changed
     pub fn remove_tags(&mut self, tag_lists: Vec<StringList>) -> bool {
         let old_tags = self.tags.clone();
         self.tags.remove_all(tag_lists);
@@ -660,7 +661,8 @@ impl PathList {
     }
 
     pub fn from_string(sources: &str, sanitize: bool) -> Result<Self> {
-        Self::from_strings(sources.split_whitespace(), sanitize)
+        let sources = parse_command::<()>(sources)?.1;
+        Self::from_strings(sources, sanitize)
     }
 
     pub fn paths(&self) -> Vec<PathBuf> {
